# autocfg
[![PyPI](https://img.shields.io/pypi/v/autocfg.svg)](https://pypi.python.org/pypi/autocfg)

All you need is a minimal config system for automl.

# Example

### Basic usages

See [basic usage](examples/basics.ipynb)

### Version control

See [version control](examples/versioning.ipynb)
